--- loncom/publisher/lonpubdir.pm	2002/06/04 13:13:38	1.25
+++ loncom/publisher/lonpubdir.pm	2003/07/05 10:07:12	1.35
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
-# (Publication Handler
+# Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.25 2002/06/04 13:13:38 www Exp $
+# $Id: lonpubdir.pm,v 1.35 2003/07/05 10:07:12 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -36,7 +36,6 @@
 # 03/23 Guy Albertelli
 # 03/24,03/29 Gerd Kortemeyer)
 # 03/31,04/03,05/09,06/23,08/18,08/20 Gerd Kortemeyer
-# 12/15 Scott Harrison
 # 12/28 Gerd Kortemeyer
 #
 ###
@@ -70,13 +69,13 @@ sub handler {
              $fn,$r->dir_config('lonDefDomain')); 
   unless (($uname) && ($udom)) {
      $r->log_reason($uname.' at '.$udom.
-         ' trying to publish file '.$ENV{'form.filename'}.
+         ' trying to list directory '.$ENV{'form.filename'}.
          ' ('.$fn.') - not authorized', 
          $r->filename); 
      return HTTP_NOT_ACCEPTABLE;
   }
 
   # Remove trailing / from direcgtory name.
 
   $fn=~s/\/$//;
 
@@ -99,7 +98,7 @@ sub handler {
 
 
 
-  startpage($r, $uname, $udom, $thisdisfn);	# Put out the start of page.
+  &startpage($r, $uname, $udom, $thisdisfn);   # Put out the start of page.
   
   # Start off the diretory table.
 
@@ -148,7 +147,9 @@ sub getEffectiveUrl {
 	#   Replace the ~username of the URL with /home/username/public_html
 	#   so that we don't have to worry about ~ expansion internally.
 	#
-	$fn=~s/^http\:\/\/[^\/]+\/\~(\w+)/\/home\/$1\/public_html/;
+	$fn=~s/^http\:\/\/[^\/]+\///;
+        $fn=~s/^\///;
+        $fn=~s/\~(\w+)/\/home\/$1\/public_html/;
 	
 	#  Remove trailing / strings (?) 
 	
@@ -176,6 +177,7 @@ sub getEffectiveUrl {
 #      $uname - User name.
 #      $udom  - Domain name the user is logged in under.
 #      $thisdisfn - Displayable version of the filename.
+
 sub startpage {
     my ($r, $uname, $udom, $thisdisfn) = @_;
     
@@ -184,11 +186,36 @@ sub startpage {
     
     $r->print('<html><head><title>LON-CAPA Construction Space</title></head>');
     
-    $r->print('<body bgcolor="#FFFFFF"><img align=right '.
-	      'src=/adm/lonIcons/lonlogos.gif>');
-    
+    $r->print(&Apache::loncommon::bodytag(undef,undef,undef,1));
+    my $pubdirscript=(<<ENDPUBDIRSCRIPT);
+<script>
+    function pubdir(theform) {
+	if (confirm('Publish complete directory?')) {
+	    theform.submit();
+        }
+    }
+   function pubrecdir(theform) {
+	if (confirm('Publish directory and all subdirectories?')) {
+            theform.pubrec.value='1';
+	    theform.submit();
+        }
+    }
+</script>
+ENDPUBDIRSCRIPT
+
     $r->print('<h1>Construction Space Directory <tt>'.
-	      $thisdisfn.'/</tt></h1>');
+	      $thisdisfn.'/</tt></h1>'.
+	      '<script type="text/javascript">top.document.title = \''.
+	      $thisdisfn.'/ - LON-CAPA Construction Space\';</script>'.
+	      $pubdirscript.
+              '<form method="post" action="/adm/publish" target="_parent">'.
+              '<table><tr><td><input type="hidden" name="filename" value="/~'.
+               $uname.$thisdisfn.'/" />'.
+              '<input type="button" onClick="pubdir(this.form);" value="Publish Directory" />'.
+              '<input type="hidden" name="pubrec" value="" />'.
+              '<input type="button" onClick="pubrecdir(this.form);" value="Publish Directory and Sub Directories" /></td><td>'.
+'<input type="button" onClick="window.location='."'/~".
+               $uname.$thisdisfn."/default.meta'".'" value="Edit Directory Catalog Information" /></td></tr><tr><td><input type="checkbox" name="forcerepub" /> Force publication of unmodified files.</td><td>&nbsp;</td></tr></table></form>');
     
     if (($uname ne $ENV{'user.name'}) || ($udom ne $ENV{'user.domain'})) {
 	$r->print('<h3>Co-Author: '.$uname.' at '.$udom.
@@ -277,19 +304,26 @@ sub putresource {
 	    if (&Apache::loncommon::fileembstyle(($filename=~/\.(\w+)$/)) eq 'ssi') {
 		$status.='<br><a href="/adm/diff?filename=/~'.$uname.
 		    $thisdisfn.'/'.$filename.
-		    '&versionone=priv" target=cat>Diffs</a>';
+		    '&versiontwo=priv" target=cat>Diffs</a>';
 	    }
 	}   
 	$status.='<br><a href="/adm/retrieve?filename=/~'.$uname.
 	    $thisdisfn.'/'.$filename.'" target=cat>Retrieve</a>';
     }
+    my $editlink='';
+    if ($filename=~/\.(xml|html|htm|xhtml|xhtm)$/) {
+	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?forceedit=1" target="_top">Edit</a>)';
+    }
+    if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library)$/) {
+	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?forceedit=1" target="_top">EditXML</a>)';
+    }
     $r->print('<tr bgcolor="'.$bgcolor.'">'.
 	      '<td><a target="_parent" href="/adm/publish?filename=/~'.
 	      $uname.$thisdisfn.'/'.$filename.'">'.'Publish</a>'.
 	      '</td>'.
 	      '<td>'.
 	      '<a href="'.$linkdir.'/'.$filename.'" target="_top">'.
-               $filename.'</a>'.
+               $filename.'</a>'.$editlink.
 	      '</td>'.
 	      '<td>'.$title.'</td>'.
 	      '<td>'.$status.'</td>'.
@@ -328,7 +362,7 @@ __END__
 
 =head1 NAME
 
-Apache::lonpubdir - Publication Handler for Directories
+Apache::lonpubdir - Construction space directory lister
 
 =head1 SYNOPSIS
@@ -70,13 +69,13 @@ sub handler {
   }
 
-  # Remove trailing / from direcgtory name.
+  # Remove trailing / from directory name.
 
   $fn=~s/\/$//;